import * as flatbuffers from 'flatbuffers';
import { Algorithm } from '../model/algorithm';
import { Cipher } from '../model/cipher';
import { Compression } from '../model/compression';
import { Curve } from '../model/curve';
import { Hash } from '../model/hash';
/**
 * KeyOptions collects a number of parameters along with sensible defaults.
 */
export declare class KeyOptions {
    bb: flatbuffers.ByteBuffer | null;
    bb_pos: number;
    __init(i: number, bb: flatbuffers.ByteBuffer): KeyOptions;
    static getRootAsKeyOptions(bb: flatbuffers.ByteBuffer, obj?: KeyOptions): KeyOptions;
    static getSizePrefixedRootAsKeyOptions(bb: flatbuffers.ByteBuffer, obj?: KeyOptions): KeyOptions;
    /**
     * The public key algorithm to use - will always create a signing primary
     * key and encryption subkey.
     */
    algorithm(): Algorithm;
    mutate_algorithm(value: Algorithm): boolean;
    /**
     * Curve configures the desired packet.Curve if the Algorithm is PubKeyAlgoECDSA,
     * PubKeyAlgoEdDSA, or PubKeyAlgoECDH. If empty Curve25519 is used.
     */
    curve(): Curve;
    mutate_curve(value: Curve): boolean;
    /**
     * Hash is the default hash function to be used.
     * If zero, SHA-256 is used.
     */
    hash(): Hash;
    mutate_hash(value: Hash): boolean;
    /**
     * Cipher is the cipher to be used.
     * If zero, AES-128 is used.
     */
    cipher(): Cipher;
    mutate_cipher(value: Cipher): boolean;
    /**
     * Compression is the compression algorithm to be
     * applied to the plaintext before encryption. If zero, no
     * compression is done.
     */
    compression(): Compression;
    mutate_compression(value: Compression): boolean;
    /**
     * CompressionLevel is the compression level to use. It must be set to
     * between -1 and 9, with -1 causing the compressor to use the
     * default compression level, 0 causing the compressor to use
     * no compression and 1 to 9 representing increasing (better,
     * slower) compression levels. If Level is less than -1 or
     * more then 9, a non-nil error will be returned during
     * encryption. See the constants above for convenient common
     * settings for Level.
     */
    compressionLevel(): number;
    mutate_compression_level(value: number): boolean;
    /**
     * RSABits is the number of bits in new RSA keys made with NewEntity.
     * If zero, then 2048 bit keys are created.
     */
    rsaBits(): number;
    mutate_rsa_bits(value: number): boolean;
    static startKeyOptions(builder: flatbuffers.Builder): void;
    static addAlgorithm(builder: flatbuffers.Builder, algorithm: Algorithm): void;
    static addCurve(builder: flatbuffers.Builder, curve: Curve): void;
    static addHash(builder: flatbuffers.Builder, hash: Hash): void;
    static addCipher(builder: flatbuffers.Builder, cipher: Cipher): void;
    static addCompression(builder: flatbuffers.Builder, compression: Compression): void;
    static addCompressionLevel(builder: flatbuffers.Builder, compressionLevel: number): void;
    static addRsaBits(builder: flatbuffers.Builder, rsaBits: number): void;
    static endKeyOptions(builder: flatbuffers.Builder): flatbuffers.Offset;
    static createKeyOptions(builder: flatbuffers.Builder, algorithm: Algorithm, curve: Curve, hash: Hash, cipher: Cipher, compression: Compression, compressionLevel: number, rsaBits: number): flatbuffers.Offset;
}
